@@ -1,6 +1,7 @@
 from docutils import nodes
 
 from sphinx.util.nodes import set_source_info
+from docutils.nodes import SkipNode
 from docutils.parsers.rst import Directive, directives
 from docutils.parsers.rst.directives import (
     admonitions,
@@ -8,6 +9,10 @@ from docutils.parsers.rst.directives import (
 from docutils.parsers.rst.roles import set_classes
 
 
+def raiseSkip(self, node):
+    raise SkipNode()
+
+
 class if_slides(nodes.Element):
     pass
 
@@ -74,7 +79,8 @@ class slideconf(nodes.Element):
     def restore(self, builder):
         """Restore the previous Slide Configuration for the Builder."""
 
-        builder.pop_theme()
+        if 'theme' in self.attributes:
+            builder.pop_theme()
 
     @classmethod
     def get(cls, doctree):
@@ -125,25 +131,45 @@ class SlideConf(Directive):
         return [node]
 
 
+def no_autoslides_filter(node):
+
+    if isinstance(node, (if_slides, slideconf, slide)):
+        return True
+
+    if (isinstance(node, nodes.section) and
+            'include-as-slide' in node.attributes.get('classes', [])):
+        node.attributes['include-as-slide'] = True
+
+        remove_classes = ['include-as-slide']
+        # see if there's a slide-level class, too
+        for cls_name in node.attributes['classes']:
+            if cls_name.startswith('slide-level-'):
+                node.attributes['level'] = int(cls_name.rsplit('-', 1)[-1])
+                remove_classes.append(cls_name)
+
+        ## for cls_name in remove_classes:
+        ##     node.attributes['classes'].remove(cls_name)
+
+        return True
+
+    return False
+
+
 def process_slideconf_nodes(app, doctree, docname):
 
     from hieroglyph import builder
 
     is_slides = builder.building_slides(app)
 
+    # if autoslides is disabled and we're building slides,
+    # replace the document tree with only explicit slide nodes
     if (is_slides and
             not slideconf.get_conf(app.builder, doctree)['autoslides']):
 
         for child in doctree.children:
-            try:
-                child.replace_self(child.traverse(slide))
-            except:
-                continue
-
-    if not is_slides:
-        # if we're not building slides, remove slideconf
-        for node in doctree.traverse(slideconf):
-            node.replace_self([])
+            child.replace_self(
+                child.traverse(no_autoslides_filter)
+            )
 
 
 class slide(nodes.admonition):
@@ -157,6 +183,7 @@ class SlideDirective(admonitions.Admonition):
         'class': directives.class_option,
         'name': directives.unchanged,
         'level': directives.nonnegative_int,
+        'inline-contents': boolean_option,
     }
 
     def run(self):
@@ -196,4 +223,7 @@ def process_slide_nodes(app, doctree, docname):
 
     # this builder does not understand slide nodes; remove them
     for node in doctree.traverse(slide):
-        node.replace_self(nodes.inline())
+        if node.attributes.get('inline-contents', False):
+            node.replace_self(node.children[1:])
+        else:
+            node.replace_self(nodes.inline())
